==> wildfly-clustering-ejb-spi-8.2.1.Final-sources.jar: org/wildfly/clustering/ejb/BeanManager.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.ejb;

/**
 * A SPI for managing beans.
 *
 * @author Paul Ferraro
 *
 * @param <G> the group identifier type
 * @param <I> the bean identifier type
 * @param <T> the bean instance type
 */
public interface BeanManager<G, I, T, B extends Batch> extends AffinitySupport<I>, BeanManagerStatistics {
    Bean<G, I, T> createBean(I id, G group, T bean);
    Bean<G, I, T> findBean(I id);

    boolean containsBean(I id);

    IdentifierFactory<G> getGroupIdentifierFactory();
    IdentifierFactory<I> getBeanIdentifierFactory();

    Batcher<B> getBatcher();

    void start();
    void stop();
}

==> wildfly-clustering-ejb-spi-27.0.0.Final-sources.jar: org/wildfly/clustering/ejb/BeanManager.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.ejb;

import java.util.concurrent.TimeoutException;
import java.util.function.Supplier;

import org.wildfly.clustering.ee.Batch;
import org.wildfly.clustering.ee.Batcher;
import org.wildfly.clustering.ee.Restartable;

/**
 * A SPI for managing beans.
 *
 * @author Paul Ferraro
 *
 * @param <I> the bean identifier type
 * @param <T> the bean instance type
 */
public interface BeanManager<I, T, B extends Batch> extends Restartable, AffinitySupport<I>, BeanManagerStatistics {
    Bean<I, T> createBean(I id, I group, T bean);
    Bean<I, T> findBean(I id) throws TimeoutException;

    boolean containsBean(I id);

    Supplier<I> getIdentifierFactory();

    Batcher<B> getBatcher();

    boolean isRemotable(Throwable throwable);
}
